# utubetomp

Converts a YouTube video to MP4 or MP3..

## Installation

```bash
$ pip install utubetomp
```

## Usage

- TODO

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`utubetomp` was created by Russian-Dev. Russian-Dev retains all rights to the source and it may not be reproduced, distributed, or used to create derivative works.

## Credits

`utubetomp` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
